
mock_response = {
  "languages" : [ "cs", "dtp", "en", "es", "fr", "ja", "nl", "nna", "tr", "tw", "zh" ],
  "lang" : "en",
  "ontologyId" : "hp",
  "loaded" : "2024-01-19T16:56:57.494460839",
  "updated" : "2024-01-19T16:56:57.494460839",
  "status" : "LOADED",
  "message" : "",
  "version" : "2024-01-16",
  "fileHash" : "null",
  "loadAttempts" : 0,
  "numberOfTerms" : 30297,
  "numberOfProperties" : 532,
  "numberOfIndividuals" : 0,
  "config" : {
    "id" : "hp",
    "versionIri" : "http://purl.obolibrary.org/obo/hp/releases/2024-01-16/hp-international.owl",
    "namespace" : "hp",
    "preferredPrefix" : "HP",
    "title" : "Human Phenotype Ontology",
    "description" : "The Human Phenotype Ontology (HPO) provides a standardized vocabulary of phenotypic abnormalities and clinical features encountered in human disease.",
    "homepage" : "http://www.human-phenotype-ontology.org/",
    "version" : "2024-01-16",
    "mailingList" : "https://groups.io/g/human-phenotype-ontology",
    "tracker" : "https://github.com/obophenotype/human-phenotype-ontology/issues/",
    "logo" : "null",
    "creators" : [ ],
    "annotations" : "null",
    "fileLocation" : "http://purl.obolibrary.org/obo/hp/hp-international.owl",
    "oboSlims" : "false",
    "labelProperty" : "http://www.w3.org/2000/01/rdf-schema#label",
    "definitionProperties" : [ ],
    "synonymProperties" : [ ],
    "hierarchicalProperties" : [ ],
    "baseUris" : [ ],
    "hiddenProperties" : [ ],
    "preferredRootTerms" : [ ],
    "isSkos" : "false",
    "allowDownload" : "false"
  },
  "baseUris" : [ ],
  "_links" : {
    "self" : {
      "href" : "http://www.ebi.ac.uk/ols4/api/ontologies/hp?lang=en"
    },
    "terms" : {
      "href" : "http://www.ebi.ac.uk/ols4/api/ontologies/hp/terms"
    },
    "properties" : {
      "href" : "http://www.ebi.ac.uk/ols4/api/ontologies/hp/properties"
    },
    "individuals" : {
      "href" : "http://www.ebi.ac.uk/ols4/api/ontologies/hp/individuals"
    }
  }
}